description_version<-function(){
cat("\n")
cat("..................................................\n\n")
cat(" .b                                                \n")
cat(" 88                                                \n")
cat(" 888oooo    .ooooo.   eoooo.   oooood8b            \n")
cat(" d88    88 d8(   )8b       )8b  888  8)            \n")
cat(" 888    88 888ooo88b o8o89888   888                \n")
cat(" 888    88 888       88(   88   888                \n")
cat("   o8ooo8   88bod8P   doooo8b  d888b             \n\n")
cat(" This report was generated using bear v2.6.1\n")
cat(" on:-",date(),"\n\n")
cat(" bear is developed by Hsin-ya Lee & Yung-jin Lee.\n")
cat(" contact: Yung-jin Lee <mobilepk at gmail.com> \n")
cat(" Kaohsiung Veterans General Hospital (HY) &\n")
cat(" ptpc inc. (YJ),\n")
cat(" Kaohsiung, Taiwan\n")
cat(" bear is under license of GPL-2|GPL-3.\n\n")
cat("..................................................\n\n")
}